@@ -2,12 +2,13 @@
 from mesures.dates import *
 from mesures.headers import MCIL345_HEADER as COLUMNS
 from mesures.parsers.dummy_data import DummyCurve
+from zipfile import ZipFile
 import os
 import pandas as pd
 
 
 class MCIL345(object):
-    def __init__(self, data, distributor=None, compression='bz2'):
+    def __init__(self, data, distributor=None, compression='bz2', version=0):
         """
         :param data: list of dicts or absolute file_path
         :param distributor: str distributor REE code
@@ -18,7 +19,7 @@ class MCIL345(object):
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'MCIL345'
-        self.version = 0
+        self.version = version
         self.distributor = distributor
         self.default_compression = compression
         self.measures_date = None
@@ -47,7 +48,7 @@ class MCIL345(object):
         filename = "{prefix}_{distributor}_{measures_date}_{timestamp}.{version}".format(
             prefix=self.prefix,
             distributor=self.distributor,
-            measures_date=self.measures_date.strftime('%Y%m'),
+            measures_date=self.measures_date[:10].replace('/', ''),
             timestamp=self.generation_date.strftime('%Y%m%d'),
             version=self.version
             )
@@ -58,11 +59,12 @@ class MCIL345(object):
 
     @property
     def zip_filename(self):
-        return "{prefix}_{distributor}_{measures_date}_{timestamp}.zip".format(
+        return "{prefix}_{distributor}_{measures_date}_{timestamp}.{version}.zip".format(
             prefix=self.prefix,
             distributor=self.distributor,
-            measures_date=self.measures_date.strftime('%Y%m'),
-            timestamp=self.generation_date.strftime('%Y%m%d')
+            measures_date=self.measures_date[:10].replace('/', ''),
+            timestamp=self.generation_date.strftime('%Y%m%d'),
+            version=self.version
         )
 
     @property
@@ -125,6 +127,8 @@ class MCIL345(object):
              'read_type': 'min'}
         ).reset_index()
 
+        df = df.sort_values(['cil', 'timestamp', 'season'])
+
         for idx, row in df.iterrows():
             ai_m = row.get('ai', 0.0)
             ae_m = row.get('ae', 0.0)
@@ -143,20 +147,33 @@ class MCIL345(object):
         :return: file path
         """
         daymin = self.file['timestamp'].min()
-        measures_date = datetime.strptime(daymin, DATE_MASK)
-        self.measures_date = measures_date
-        file_path = os.path.join('/tmp', self.filename)
+        daymax = self.file['timestamp'].max()
+        self.measures_date = daymin
+        zipped_file = ZipFile(os.path.join('/tmp', self.zip_filename), 'w')
+        while daymin <= daymax:
+            di = daymin
+            df = (datetime.strptime(daymin, DATE_MASK) + timedelta(days=1)).strftime(DATE_MASK)
+            self.measures_date = di
+            dataf = self.file[(self.file['timestamp'] >= di) & (self.file['timestamp'] < df)]
+            # dataf['timestamp'] = dataf['timestamp'].apply(lambda x: x.strftime(DATETIME_HOUR_MASK))
 
-        kwargs = {'sep': ';',
-                  'header': False,
-                  'columns': COLUMNS,
-                  'index': False,
-                  'line_terminator': ';\n'
-                  }
+            existing_files = os.listdir('/tmp')
+            if existing_files:
+                max_version = max([int(f.split('.')[1]) for f in existing_files if self.zip_filename.split('.')[0] in f])
+                self.version = max_version + 1
 
-        if self.default_compression:
-            kwargs.update({'compression': self.default_compression})
+            file_path = os.path.join('/tmp', self.filename)
+            kwargs = {'sep': ';',
+                      'header': False,
+                      'columns': self.columns,
+                      'index': False,
+                      'line_terminator': ';\n'
+                      }
+            if self.default_compression:
+                kwargs.update({'compression': self.default_compression})
 
-        self.file.to_csv(file_path, **kwargs)
-
-        return file_path
+            dataf.to_csv(file_path, **kwargs)
+            daymin = df
+            zipped_file.write(file_path, arcname=os.path.basename(file_path))
+        zipped_file.close()
+        return zipped_file.filename
